package com.convenient.android.lib

import android.app.Activity
import android.app.Application
import android.content.Context
import android.content.Intent
import android.os.Bundle
import androidx.lifecycle.*
import com.composition.android.lib.ad.AdLoad
import com.convenient.android.common.base.ActivitysUtils
import com.convenient.android.common.extension.readyGo
import com.convenient.android.lib.ui.ad.activity.AppWelcomeActivity
import com.convenient.android.lib.ui.ad.model.Datas
import kotlinx.coroutines.launch

/**
 * @classname:
 * @author: LiuXiaoLong
 * @date: 2022/9/6
 * description:
 */
class LibApplication : Application(), LifecycleEventObserver {

    companion object{

        lateinit var context: Context

    }

    override fun onCreate() {
        super<Application>.onCreate()
        context = applicationContext
        registerActivityLifecycleCallbacks()
        ProcessLifecycleOwner.get().lifecycle.addObserver(this)
    }

    override fun onStateChanged(source: LifecycleOwner, event: Lifecycle.Event) {
        when(event){
            Lifecycle.Event.ON_START->{
                ProcessLifecycleOwner.get().lifecycleScope.launch {
                    if (AdLoad.hasCacheAd(Datas.APP_OPEN) && Datas.bgShowAppOpen) {
                        readyGo(AppWelcomeActivity::class.java){
                            it.flags = Intent.FLAG_ACTIVITY_NEW_TASK
                            it.putExtra(AppWelcomeActivity.ONLY_SHOW, true)
                        }
                    }
                }
            }
            Lifecycle.Event.ON_PAUSE->{
                if (Datas.bgShowAppOpen){
                    ProcessLifecycleOwner.get().lifecycleScope.launch {
                        ActivitysUtils.current()?.let {
                            AdLoad.preloadAd(it, Datas.APP_OPEN)
                        }
                    }
                }
            }
            else->{

            }

        }
    }


    private fun registerActivityLifecycleCallbacks() {

        registerActivityLifecycleCallbacks(object : ActivityLifecycleCallbacks {

            override fun onActivitySaveInstanceState(activity: Activity, outState: Bundle) {}

            override fun onActivityCreated(activity: Activity, savedInstanceState: Bundle?) {
                ActivitysUtils.add(activity = activity)
            }


            override fun onActivityStarted(activity: Activity) {

            }

            override fun onActivityResumed(activity: Activity) {}

            override fun onActivityPaused(activity: Activity) {}

            override fun onActivityStopped(activity: Activity) {

            }

            override fun onActivityDestroyed(activity: Activity) {
                ActivitysUtils.remove(activity = activity)

            }

        })
    }


}