package com.composition.android.lib.ad.util

import android.util.Log
import com.composition.android.lib.ad.AdManager
import com.composition.android.lib.ad.bean.AdUnitBean
import com.composition.android.lib.ad.interfaces.IAdFormatRequest


fun adLog(tag: String = AdManager.TAG, msg: String?) {
    if (AdManager.instance.logEnable) {
        msg?.let {
            println("$tag: $msg")
        }
    }
}

fun adLogWithFrame(tag: String = AdManager.TAG, msg: String?) {
    adLog(tag, "┌─────────────────────────────────────────")
    adLog(tag, "│ $msg")
    adLog(tag, "└─────────────────────────────────────────")
}

fun adLogWithFrame(tag: String = AdManager.TAG, vararg msgs: String) {
    adLog(tag, "┌─────────────────────────────────────────")
    for (value in msgs) {
        adLog(tag, "│ $value")
    }
    adLog(tag, "└─────────────────────────────────────────")
}

fun adLogE(tag: String, msg: String?) {
    if (AdManager.instance.logEnable) {
        msg?.let {
            System.err.println()
            System.err.println("$tag: ┌─────────────────────────────────────────")
            System.err.println("$tag: │ $msg")
            System.err.println("$tag: └─────────────────────────────────────────")
        }
    }
}


fun printAdFailInfo(adBean: AdUnitBean, code: Int, msg: String?) {
    adLogWithFrame(msgs = mutableListOf<String>("广告加载失败").apply {
        addAll(adBean.logInfo())
        add("错误码:${code}")
        add("错误信息:${msg}")
    }.toTypedArray())
}

fun printAdInfo(adBean: AdUnitBean, vararg extraInfo : String) {
    adLogWithFrame(msgs = mutableListOf<String>("广告加载成功",).apply {
        addAll(adBean.logInfo())
        addAll(extraInfo)
    }.toTypedArray())
}

