package com.composition.android.ad.csj.load.request

import android.content.Context
import com.bytedance.sdk.openadsdk.*
import com.composition.android.lib.ad.basic.AdResult
import com.composition.android.lib.ad.bean.AdUnitBean
import com.composition.android.lib.ad.interfaces.IAdFormatRequest
import com.composition.android.lib.ad.util.adLog
import com.composition.android.lib.ad.util.isActiveResult
import com.composition.android.lib.ad.util.printAdFailInfo
import com.composition.android.lib.ad.util.printAdInfo
import kotlinx.coroutines.suspendCancellableCoroutine

/**
 * @classname:
 * @author: LiuXiaoLong
 * @date: 2022/9/13
 * description:穿山甲激励广告加载
 */
class CSJInterstitialRequestImpl : IAdFormatRequest {
    override suspend fun load(context: Context, adUnitBean: AdUnitBean): AdResult {
        return suspendCancellableCoroutine {

            val adSlot = AdSlot.Builder()
                .setCodeId(adUnitBean.adUnitId)
                .setSupportDeepLink(true)
                .setAdCount(1)
                .setOrientation(TTAdConstant.VERTICAL)
                .setAdLoadType(TTAdLoadType.PRELOAD)
                .setExpressViewAcceptedSize(1080F, 1920F)
                .build()

            TTAdSdk.getAdManager().createAdNative(context)
                .loadFullScreenVideoAd(adSlot, object : TTAdNative.FullScreenVideoAdListener {
                    override fun onError(p0: Int, p1: String?) {
                        printAdFailInfo(adUnitBean, p0, p1)
                        it.isActiveResult(AdResult.Fail(adUnitBean, msg = p1 ?: "穿山甲广告-模板插屏-加载失败"))
                    }

                    override fun onFullScreenVideoAdLoad(p0: TTFullScreenVideoAd?) {
                    }

                    override fun onFullScreenVideoCached() {
                    }

                    override fun onFullScreenVideoCached(p0: TTFullScreenVideoAd?) {
                        if (p0 != null) {
                            printAdInfo(adUnitBean)
                            it.isActiveResult(AdResult.Success(adBean = adUnitBean, adObject = p0, msg = "穿山甲广告-模板插屏-加载成功"))
                        } else {
                            printAdFailInfo(adUnitBean, 0, "SDK返回的广告实例为空")
                            it.isActiveResult(AdResult.Fail(adUnitBean, msg = "穿山甲广告-模板插屏-加载失败，SDK返回的广告实例为空"))
                        }
                    }
                })
        }
    }
}