package com.composition.android.ad.gromore.impl

import android.content.Context
import com.bytedance.sdk.openadsdk.TTAdConfig
import com.bytedance.sdk.openadsdk.TTAdSdk
import com.bytedance.sdk.openadsdk.TTCustomController
import com.bytedance.sdk.openadsdk.mediation.init.MediationConfig
import com.bytedance.sdk.openadsdk.mediation.init.MediationConfigUserInfoForSegment
import com.composition.android.ad.gromore.load.GroMoreAdLoader
import com.composition.android.ad.gromore.mediation.AdnLocalExtraConfig
import com.composition.android.lib.ad.AdManager
import com.composition.android.lib.ad.interfaces.AdLoader
import com.composition.android.lib.ad.interfaces.Initialize
import com.composition.android.lib.ad.util.adLogE

/**
 * @classname:
 * @author: LiuXiaoLong
 * @date: 2022/9/15
 * description:GroMore SDK初始化
 */
class GroMoreInitialize(var appId: String) : Initialize {

    override fun init(context: Context) {
        val userInfo = MediationConfigUserInfoForSegment()

        val customInfos: MutableMap<String, String> = HashMap()

        userInfo.customInfos = customInfos

        val mediationExtra = mapOf(
            AdnLocalExtraConfig.EXTRA_AGREE_AGREEMENT to true,
            AdnLocalExtraConfig.EXTRA_UNION_ADN_CHANNEL_ID to 8,
            AdnLocalExtraConfig.EXTRA_IS_LIMIT_PERSONAL_AD to true
        )

        val result = TTAdSdk.init(
            context, TTAdConfig.Builder()
                .appId(appId)
                .useTextureView(true)
                .appName(context.packageName)
                .supportMultiProcess(true)
                .debug(AdManager.instance.isDebug)
                .useMediation(true)
                .customController(object : TTCustomController() {

                })
                .setMediationConfig(
                    MediationConfig.Builder()
                        .setLocalExtra(mediationExtra)
                        .build()
                )
                .build()
        )

        TTAdSdk.start(object : TTAdSdk.Callback {
            override fun success() {
                adLogE(AdManager.TAG, "GroMoreSDK初始化完成 ---- 版本号:${TTAdSdk.getAdManager().sdkVersion}")

            }

            override fun fail(p0: Int, p1: String?) {
                adLogE(AdManager.TAG, "GroMoreSDK初始化失败")

            }

        })

    }

    override fun getAdLoader(): AdLoader {
        return GroMoreAdLoader()
    }
}