package com.composition.android.ad.gromore.load.request

import android.app.Activity
import android.content.Context
import com.beizi.fusion.SplashAd
import com.bytedance.sdk.openadsdk.*
import com.bytedance.sdk.openadsdk.mediation.ad.MediationAdSlot
import com.composition.android.lib.ad.AdManager
import com.composition.android.lib.ad.basic.AdResult
import com.composition.android.lib.ad.bean.AdUnitBean
import com.composition.android.lib.ad.interfaces.IAdFormatRequest
import com.composition.android.lib.ad.util.*
import kotlinx.coroutines.suspendCancellableCoroutine

/**
 * @classname:
 * @author: LiuXiaoLong
 * @date: 2022/9/16
 * description:GroMore开屏广告加载类
 */
class GMAppOpenRequestImpl : IAdFormatRequest {
    override suspend fun load(context: Context, adUnitBean: AdUnitBean): AdResult {
        return suspendCancellableCoroutine {
            if (context is Activity) {
                val adSlot = AdSlot.Builder()
                    .setCodeId(adUnitBean.adUnitId)
                    .setImageAcceptedSize(getScreenWidth(context), getScreenHeight(context))
                    .setMediationAdSlot(MediationAdSlot.Builder()
                        .setBidNotify(true)
                        .build())
                    .build()

                TTAdSdk.getAdManager().createAdNative(context)
                    .loadSplashAd(adSlot, object : TTAdNative.CSJSplashAdListener{

                        override fun onSplashLoadSuccess(p0: CSJSplashAd?) {
                        }

                        override fun onSplashLoadFail(p0: CSJAdError) {
                            printAdFailInfo(adUnitBean, p0.code, p0.msg)
                            it.isActiveResult(AdResult.Fail(adBean = adUnitBean, msg = p0.msg ?: "GroMore-开屏-加载失败"))
                        }

                        override fun onSplashRenderSuccess(splashAd: CSJSplashAd?) {
                            printAdInfo(adUnitBean)
                            it.isActiveResult(AdResult.Success(adBean = adUnitBean, adObject = splashAd, msg = "GroMore-开屏-加载成功"))
                        }

                        override fun onSplashRenderFail(p0: CSJSplashAd?, p1: CSJAdError?) {

                        }
                    }, adUnitBean.requestAdConfig.adLoadTimeOut.toInt())
            } else {
                printAdFailInfo(adUnitBean, 0, "GroMore广告-开屏-加载失败：context需要为Activity")
                it.isActiveResult(AdResult.Fail(adUnitBean, msg = "GroMore广告-开屏-加载失败：context需要为Activity"))
            }
        }
    }
}