package com.composition.android.ad.gromore.load.request

import android.content.Context
import com.bytedance.sdk.openadsdk.AdSlot
import com.bytedance.sdk.openadsdk.TTAdLoadType
import com.bytedance.sdk.openadsdk.TTAdNative
import com.bytedance.sdk.openadsdk.TTAdSdk
import com.bytedance.sdk.openadsdk.TTFeedAd
import com.bytedance.sdk.openadsdk.mediation.ad.MediationAdSlot
import com.composition.android.lib.ad.AdManager
import com.composition.android.lib.ad.basic.AdResult
import com.composition.android.lib.ad.bean.AdUnitBean
import com.composition.android.lib.ad.interfaces.IAdFormatRequest
import com.composition.android.lib.ad.util.*
import kotlinx.coroutines.suspendCancellableCoroutine

class GMFeedRequestImpl : IAdFormatRequest {

    override suspend fun load(context: Context, adUnitBean: AdUnitBean): AdResult {

        return suspendCancellableCoroutine {
            val size = if (adUnitBean.adSize != null && adUnitBean.adSize!!.isAvailable()) {
                adUnitBean.adSize!!.widthPx to adUnitBean.adSize!!.heightPx
            } else {
                getScreenWidth(context) to 320
            }

            val adSlot = AdSlot.Builder()
                .setCodeId(adUnitBean.adUnitId)
                .setSupportDeepLink(true)
                .setAdCount(1)
                .setImageAcceptedSize(size.first, size.second)
                .setExpressViewAcceptedSize(px2dip(context, size.first.toFloat()).toFloat(), px2dip(context, size.second.toFloat()).toFloat())
                .setAdLoadType(TTAdLoadType.PRELOAD)
                .setMediationAdSlot(
                    MediationAdSlot.Builder()
                    .setBidNotify(true)
                    .build())
                .build()
            adLogE(tag = AdManager.TAG, msg = "GroMore-信息流广告-开始加载")
            TTAdSdk.getAdManager().createAdNative(context)
                .loadFeedAd(adSlot, object : TTAdNative.FeedAdListener {
                    override fun onError(p0: Int, p1: String?) {
                        printAdFailInfo(adUnitBean, p0, p1)
                        it.isActiveResult(AdResult.Fail(adUnitBean, msg = p1 ?: "GroMore广告-信息流广告-加载失败"))
                    }

                    override fun onFeedAdLoad(p0: MutableList<TTFeedAd>?) {
                        if (p0.isNullOrEmpty().not()) {
                            printAdInfo(adUnitBean)
                            it.isActiveResult(AdResult.Success(adBean = adUnitBean, adObject = p0?.get(0), msg = "GroMore-信息流广告-加载成功"))
                        } else {
                            printAdFailInfo(adUnitBean, 0, "SDK返回的广告实例为空")
                            it.isActiveResult(AdResult.Fail(adUnitBean, msg = "GroMore信息流广告-加载失败, SDK返回的广告实例为空"))
                        }
                    }
                })
        }
    }
}