package com.composition.android.ad.gromore.load.request

import android.content.Context
import com.bytedance.sdk.openadsdk.*
import com.bytedance.sdk.openadsdk.mediation.ad.MediationAdSlot
import com.composition.android.lib.ad.AdManager
import com.composition.android.lib.ad.basic.AdResult
import com.composition.android.lib.ad.bean.AdUnitBean
import com.composition.android.lib.ad.interfaces.IAdFormatRequest
import com.composition.android.lib.ad.util.*
import kotlinx.coroutines.suspendCancellableCoroutine

/**
 * @classname:
 * @author: LiuXiaoLong
 * @date: 2022/9/16
 * description: GroMore原生模板广告加载类
 */
class GMNativeTemplateRequestImpl : IAdFormatRequest {
    override suspend fun load(context: Context, adUnitBean: AdUnitBean): AdResult {
        return suspendCancellableCoroutine {
            val size = if (adUnitBean.adSize != null && adUnitBean.adSize!!.isAvailable()) {
                adUnitBean.adSize!!.widthPx to adUnitBean.adSize!!.heightPx
            } else {
                getScreenWidth(context) to 320
            }
            adLogE(tag = AdManager.TAG, msg = "GroMore-原生模板-开始加载")
            val adSlot = AdSlot.Builder()
                .setCodeId(adUnitBean.adUnitId)
                .setAdCount(1)
                .setImageAcceptedSize(size.first, size.second)
                .setAdLoadType(TTAdLoadType.PRELOAD)
                .setMediationAdSlot(
                    MediationAdSlot.Builder()
                    .setBidNotify(true)
                    .build())
                .build()

            TTAdSdk.getAdManager().createAdNative(context)
                .loadNativeExpressAd(adSlot, object : TTAdNative.NativeExpressAdListener {
                    override fun onError(p0: Int, p1: String?) {
                        printAdFailInfo(adUnitBean, p0, p1)
                        it.isActiveResult(AdResult.Fail(adUnitBean, msg = p1 ?: "GroMore-原生模板-加载失败"))
                    }

                    override fun onNativeExpressAdLoad(p0: MutableList<TTNativeExpressAd>?) {
                        if (p0.isNullOrEmpty().not()) {
                            printAdInfo(adUnitBean)
                            it.isActiveResult(AdResult.Success(adBean = adUnitBean, adObject = p0?.get(0), msg = "GroMore-原生模板-加载成功"))
                        } else {
                            printAdFailInfo(adUnitBean, 0, "SDK返回的广告实例为空")
                            it.isActiveResult(AdResult.Fail(adUnitBean, msg = "GroMore原生模板-加载失败, SDK返回的广告实例为空"))
                        }
                    }
                })
        }
    }
}