package com.composition.android.ad.gromore.load.view

import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.appcompat.widget.AppCompatImageView
import androidx.appcompat.widget.AppCompatTextView
import androidx.core.view.isVisible
import com.bytedance.sdk.openadsdk.TTAdConstant
import com.bytedance.sdk.openadsdk.TTAdDislike
import com.bytedance.sdk.openadsdk.TTFeedAd
import com.bytedance.sdk.openadsdk.TTNativeAd
import com.composition.android.ad.gromore.R
import com.composition.android.ad.gromore.impl.GMAppDownloadListener
import com.composition.android.lib.ad.AdManager
import com.composition.android.lib.ad.basic.AdResult
import com.composition.android.lib.ad.basic.BasicAdView
import com.composition.android.lib.ad.basic.NativeAdViewHolder
import com.composition.android.lib.ad.util.adLog
import com.composition.android.lib.ad.util.adLogE
import com.composition.android.lib.ad.util.parentRemove

/**
 * @classname:
 * @author: LiuXiaoLong
 * @date: 2022/9/13
 * description: GroMore 信息流广告View
 */
class GMTTFeedAdView(context: Context?) : BasicAdView<View>(context) {

    private var viewHolder: NativeAdViewHolder? = null

    fun setViewHolder(viewHolder: NativeAdViewHolder) {
        this.viewHolder = viewHolder
    }

    override fun adContentView(): View? {
        if (adResult == null || viewHolder == null) {
            return null
        }
        val ttFeedAd = adResult?.adObject as? TTFeedAd
        ttFeedAd?.render()
        if (ttFeedAd?.mediationManager?.isExpress == true){
            return ttFeedAd.adView ?: null
        } else{
            return null
        }
    }

    override fun onResume() {

    }

    override fun onPause() {

    }

    override fun onDestroy() {
        val ttFeedAd = adResult?.adObject as? TTFeedAd
        ttFeedAd?.destroy()
        adResult?.adObject = null
    }

    companion object {

        fun populateFeedAdView(context: Context, adResult: AdResult.Success, viewHolder: NativeAdViewHolder, advertisersContainerView: ViewGroup?) {

            val ttFeedAd = adResult.adObject as TTFeedAd
            viewHolder.activity?.apply {
                ttFeedAd.setDislikeCallback(this, object : TTAdDislike.DislikeInteractionCallback {
                    override fun onShow() {

                    }

                    override fun onSelected(p0: Int, p1: String?, p2: Boolean) {
                        adLog(msg = "穿山甲广告-原生-点击不喜欢按钮")
                        viewHolder.adListener?.onAdDisLike()
                    }

                    override fun onCancel() {
                    }
                })
            }
            if (ttFeedAd.mediationManager.isExpress) {
                ttFeedAd.setExpressRenderListener { view, _, _, _ ->
                    advertisersContainerView?.removeAllViews()
                    view?.parentRemove()
                    advertisersContainerView?.addView(ttFeedAd.adView)
                }
                ttFeedAd.render()
            } else {
                viewHolder.titleView?.text = ttFeedAd.title
                (viewHolder.titleDescView as? AppCompatTextView)?.text = ttFeedAd.description

                val mediaImageViews = LayoutInflater.from(context).inflate(R.layout.csj_native_ad_media_image_views, null)

                val imageViewList = mutableListOf<View>()
                imageViewList.add(mediaImageViews.findViewById(R.id.id_ad_media_iv_1))
                imageViewList.add(mediaImageViews.findViewById(R.id.id_ad_media_iv_2))
                imageViewList.add(mediaImageViews.findViewById(R.id.id_ad_media_iv_3))

                viewHolder.contentMediaViewGroup?.apply {
                    removeAllViews()
                    addView(mediaImageViews)
                }
                if (ttFeedAd.imageList.isNullOrEmpty().not()) {

                    for (i in 0..2) {
                        val imageItem = ttFeedAd.imageList.getOrNull(i)
                        if (imageItem != null) {
                            if (imageItem.isValid) {
                                viewHolder.mediaImageLoader?.displayImage(context, imageItem.imageUrl, imageViewList[i] as AppCompatImageView)
                            }
                        } else {
                            imageViewList.getOrNull(i)?.isVisible = false
                        }
                    }
                }
                if (ttFeedAd.icon != null && ttFeedAd.icon.isValid && viewHolder.iconView != null) {
                    viewHolder.iconImageLoader?.displayImage(context, ttFeedAd.icon.imageUrl, viewHolder.iconView as AppCompatImageView)
                }
                when (ttFeedAd.interactionType) {
                    TTAdConstant.INTERACTION_TYPE_DOWNLOAD -> {
                        ttFeedAd.setActivityForDownloadApp(viewHolder.activity)
                        viewHolder.callActionButtonView?.isVisible = true
                        ttFeedAd.setDownloadListener(GMAppDownloadListener(context, viewHolder))
                    }
                    TTAdConstant.INTERACTION_TYPE_DIAL -> {
                        viewHolder.callActionButtonView?.also {
                            it.isVisible = true
                            it.text = context.getString(R.string.call_now)
                        }
                    }
                    TTAdConstant.INTERACTION_TYPE_LANDING_PAGE -> {
                        viewHolder.callActionButtonView?.also {
                            it.isVisible = true
                            it.text = context.getString(R.string.check_the_details)
                        }
                    }
                    else -> {
                        viewHolder.callActionButtonView?.isVisible = false
                    }
                }

                (viewHolder.advertiserLogoImageView as? AppCompatImageView)?.setImageBitmap(ttFeedAd.adLogo)

                val clickViewList = mutableListOf<View>()
                viewHolder.customLayoutRootView?.let { clickViewList.add(it) }

                val creativeViewList = mutableListOf<View>()
                viewHolder.callActionButtonView?.let {
                    creativeViewList.add(it)
                }
                adLogE(tag = AdManager.TAG, msg = "GroMore-Feed广告-isExpress:${ttFeedAd.mediationManager.isExpress}")
                ttFeedAd.registerViewForInteraction(
                    viewHolder.customLayoutRootView as ViewGroup,
                    imageViewList,
                    clickViewList,
                    creativeViewList,
                    viewHolder.dislikeView,
                    object : TTNativeAd.AdInteractionListener {
                        override fun onAdClicked(p0: View?, p1: TTNativeAd?) {
                            adLog(msg = "穿山甲广告-原生-点击广告")
                            viewHolder.adListener?.onAdClick()
                        }

                        override fun onAdCreativeClick(p0: View?, p1: TTNativeAd?) {
                        }

                        override fun onAdShow(p0: TTNativeAd?) {
                            adLog(msg = "穿山甲广告-原生-广告展示")
                        }

                    })

                ttFeedAd.setExpressRenderListener { _, width, height, _ ->
                    adLog(AdManager.TAG, "穿山甲广告-原生-渲染成功 width:${width},height:${height}")
                    viewHolder.adListener?.onAdShow(adResult.adBean)
                }
                ttFeedAd.render()
            }
        }
    }

    override fun onDetachedFromWindow() {
        super.onDetachedFromWindow()
        adResult?.adObject = null
    }
}