package com.composition.android.ad.gromore.beizis

import android.content.Context
import com.beizi.fusion.BeiZiCustomController
import com.beizi.fusion.BeiZis
import com.bytedance.sdk.openadsdk.mediation.bridge.custom.MediationCustomInitLoader
import com.bytedance.sdk.openadsdk.mediation.custom.MediationCustomInitConfig
import com.composition.android.ad.gromore.mediation.AdnLocalExtraConfig
import com.composition.android.lib.ad.util.adLogWithFrame
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.GlobalScope
import kotlinx.coroutines.async
import kotlinx.coroutines.launch

/**
 * @author: HuBoWen
 * @date: 2023/5/4
 * @description:
 */
class BeiZiInitialize : MediationCustomInitLoader() {

    override fun initializeADN(context: Context?, customInitConfig: MediationCustomInitConfig?, localExtra: MutableMap<String, Any>?) {
        if (!isInit) {
            GlobalScope.launch(Dispatchers.IO) {
                async(Dispatchers.Main) {
                    val agreeAgreement = localExtra?.get(AdnLocalExtraConfig.EXTRA_AGREE_AGREEMENT) as? Boolean ?: false
                    val limitPersonalAds = localExtra?.get(AdnLocalExtraConfig.EXTRA_IS_LIMIT_PERSONAL_AD) as? Boolean ?: true
                    val appId = customInitConfig?.appId
                    adLogWithFrame("广告", "BenZi广告初始化: appID:${appId}, 个性化广告：${limitPersonalAds}")
                    BeiZis.init(context, appId, object : BeiZiCustomController() {
                        override fun isCanUseGaid(): Boolean {
                            return agreeAgreement
                        }

                        override fun isCanUseLocation(): Boolean {
                            return agreeAgreement
                        }

                        override fun isCanUseOaid(): Boolean {
                            return agreeAgreement
                        }

                        override fun isCanUsePhoneState(): Boolean {
                            return agreeAgreement
                        }

                        override fun isCanUseWifiState(): Boolean {
                            return agreeAgreement
                        }
                    })
                    BeiZis.setLimitPersonalAds(limitPersonalAds)
                }.await()
                adLogWithFrame("广告", "BenZi广告初始化完成:${BeiZis.isIsSyncInit()} 线程:${Thread.currentThread().name}")
                callInitSuccess()
            }
        }
    }

    override fun getNetworkSdkVersion(): String {
        return BeiZis.getSdkVersion()
    }
}