package com.composition.android.ad.gromore.union

import android.app.Activity
import android.content.Context
import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import android.widget.LinearLayout
import androidx.core.view.isVisible
import com.bytedance.sdk.openadsdk.AdSlot
import com.bytedance.sdk.openadsdk.mediation.MediationConstant
import com.bytedance.sdk.openadsdk.mediation.bridge.custom.banner.MediationCustomBannerLoader
import com.bytedance.sdk.openadsdk.mediation.custom.MediationCustomServiceConfig
import com.composition.android.lib.ad.util.adLogWithFrame
import com.composition.android.lib.ad.util.getScreenWidth
import com.qq.e.ads.banner2.UnifiedBannerADListener
import com.qq.e.ads.banner2.UnifiedBannerView
import com.qq.e.comm.pi.IBidding
import com.qq.e.comm.util.AdError
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.GlobalScope
import kotlinx.coroutines.launch
import java.util.Locale


/**
 * @classname: GroMore 自定义广告 --- 优量汇ADN  横幅广告
 * @author: LiuXiaoLong
 * @date: 2023/9/18
 * description:
 */
class CustomUnionBannerRequestImpl : MediationCustomBannerLoader() ,UnifiedBannerADListener{


    private var unifiedBannerView: UnifiedBannerView? = null


    override fun load(context: Context?, adSlot: AdSlot?, serviceConfig: MediationCustomServiceConfig?) {
        GlobalScope.launch(Dispatchers.IO) {
            adLogWithFrame(
                msgs = arrayOf(
                    "加载GroMore自定义广告",
                    "广告商:优量汇(Union)",
                    "广告ID:${serviceConfig?.adnNetworkSlotId}"
                )
            )
            if (context !is Activity) {
                callLoadFail(0, "加载GroMore自定义广告-优量汇(Union)-横幅广告必须使用Activity")
                return@launch
            }
            if (serviceConfig?.subAdtype == MediationConstant.SUB_ADTYPE_BANNER) {
                unifiedBannerView = UnifiedBannerView(context, serviceConfig.adnNetworkSlotId, this@CustomUnionBannerRequestImpl)
                unifiedBannerView?.setRefresh(0)
                unifiedBannerView?.loadAD()
            }else{
                callLoadFail(0, "GroMore-横幅-自定义优量汇(Union), 未实现优量汇(Union)信息流广告样式")
            }
        }
    }


    override fun isReadyCondition(): MediationConstant.AdIsReadyStatus {
        if (unifiedBannerView == null) {
            adLogWithFrame(msgs = arrayOf("GroMore-横幅-自定义优量汇(Union), unifiedBannerView为空， 还未准备好"))
            return MediationConstant.AdIsReadyStatus.AD_IS_NOT_READY
        }
        return if (unifiedBannerView?.isValid == true) MediationConstant.AdIsReadyStatus.AD_IS_READY else MediationConstant.AdIsReadyStatus.AD_IS_NOT_READY
    }

    override fun getAdView(): View? {
        adLogWithFrame(msgs = arrayOf("GroMore-横幅-自定义优量汇(Union), 获取横幅View"))
        if (unifiedBannerView != null){
            return getUnifiedBannerLayoutParams()?.let {
                val linearLayout = LinearLayout(unifiedBannerView?.context)
                linearLayout.addView(unifiedBannerView, it)
                linearLayout
            }?: unifiedBannerView!!
        }else{
            return null
        }
    }

    /**
     * Banner 规定banner宽高比应该为6.4:1 , 开发者可自行设置符合规定宽高比的具体宽度和高度值
     *
     * @return
     */
    private fun getUnifiedBannerLayoutParams(): FrameLayout.LayoutParams? {
        unifiedBannerView?.context?.let {
            val screenWidth = getScreenWidth(it)
            return FrameLayout.LayoutParams(screenWidth, Math.round(screenWidth / 6.4F))
        } ?: return null
    }

    override fun onPause() {
        super.onPause()
    }

    override fun onDestroy() {
        super.onDestroy()
        adLogWithFrame(msgs = arrayOf("GroMore-横幅-自定义优量汇(Union), onDestroy销毁广告"))
        unifiedBannerView?.destroy()
    }

    override fun receiveBidResult(win: Boolean, winnerPrice: Double, loseReason: Int, extra: MutableMap<String, Any>?) {
        super.receiveBidResult(win, winnerPrice, loseReason, extra)
        val reason = when (loseReason) {
            1 -> "价格较低"
            2 -> "广告返回超时"
            10001 -> "其他原因"
            -1 -> "胜出"
            else -> {
                ""
            }
        }
        adLogWithFrame(
            msgs = arrayOf(
                "GroMore-开屏-自定义优量汇(Union)",
                "竞价结果:${if (win) "竞价胜利" else "竞价输了"}",
                "竞价胜利价格:${winnerPrice}",
                "失败原因:${reason}",
                "extra: $extra"
            )
        )
        if (win) {
            if (winnerPrice > 0) {
                unifiedBannerView?.sendWinNotification(
                    mapOf(
                        IBidding.EXPECT_COST_PRICE to winnerPrice
                    )
                )
            }
        } else {
            if (loseReason == 1) {
                unifiedBannerView?.sendLossNotification(
                    mapOf(
                        IBidding.LOSS_REASON to 2 // 其他广告出价更高
                    )
                )
            }
        }
    }

    override fun onNoAD(adError: AdError) {
        val msg = String.format(
            Locale.getDefault(), "onNoAD, error code: %d, error msg: %s",
            adError.errorCode, adError.errorMsg
        )
        callLoadFail(adError.errorCode, msg)
    }

    override fun onADReceive() {
        unifiedBannerView?.let {
            if (biddingType == MediationConstant.AD_TYPE_CLIENT_BIDING) {
                var epcm = unifiedBannerView?.ecpm?.toDouble()
                epcm?.apply {
                    adLogWithFrame(msgs = arrayOf("GroMore-横幅-自定义优量汇(Union), 客户端竞价，ecpm:${this}"))
                    if (this < 0) {
                        epcm = 0.0
                    }
                    callLoadSuccess(epcm!!)
                }
            } else {
                adLogWithFrame(msgs = arrayOf("GroMore-横幅-自定义优量汇(Union), 竞价方式:${biddingType}"))
                callLoadSuccess()
            }
        }

    }

    override fun onADExposure() {
    }

    override fun onADClosed() {
        adLogWithFrame(msg = "GroMore-横幅-自定义优量汇(Union)- 广告关闭")
        callBannerAdClosed()
        try {
            val parentView = unifiedBannerView?.parent
            if (parentView != null && parentView is ViewGroup) {
                parentView.removeAllViews()
                parentView.isVisible = false
            }
        }catch (e : Exception){

        }
    }

    override fun onADClicked() {
        adLogWithFrame(msg = "GroMore-横幅-自定义优量汇(Union)- 点击")
        callBannerAdClick()
    }

    override fun onADLeftApplication() {
    }
}