package com.composition.android.ad.gromore.union

import android.app.Activity
import android.content.Context
import com.bytedance.sdk.openadsdk.AdSlot
import com.bytedance.sdk.openadsdk.mediation.MediationConstant
import com.bytedance.sdk.openadsdk.mediation.bridge.custom.interstitial.MediationCustomInterstitialLoader
import com.bytedance.sdk.openadsdk.mediation.custom.MediationCustomServiceConfig
import com.composition.android.lib.ad.util.adLogWithFrame
import com.qq.e.ads.cfg.VideoOption
import com.qq.e.ads.interstitial2.UnifiedInterstitialAD
import com.qq.e.ads.interstitial2.UnifiedInterstitialADListener
import com.qq.e.comm.pi.IBidding
import com.qq.e.comm.util.AdError
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.GlobalScope
import kotlinx.coroutines.launch
import java.util.Locale

/**
 * @classname: GroMore 自定义广告 --- 优量汇ADN  插屏广告
 * @author: LiuXiaoLong
 * @date: 2023/9/19
 * description:
 */
class CustomUnionInterstitialRequestImpl : MediationCustomInterstitialLoader() {

    private var interstitialAd: UnifiedInterstitialAD? = null

    override fun load(context: Context?, adSlot: AdSlot?, config: MediationCustomServiceConfig?) {
        GlobalScope.launch(Dispatchers.IO) {
            adLogWithFrame(
                msgs = arrayOf(
                    "加载GroMore自定义广告-插屏",
                    "广告商:优量汇(Union)",
                    "广告ID:${config?.adnNetworkSlotId}"
                )
            )
            if (context !is Activity) {
                callLoadFail(0, "加载GroMore自定义广告-优量汇(Union)-横幅广告必须使用Activity")
                return@launch
            }
            interstitialAd = UnifiedInterstitialAD(context, config?.adnNetworkSlotId, object : UnifiedInterstitialADListener {
                override fun onADReceive() {
                    adLogWithFrame(msgs = arrayOf("GroMore-插屏-自定义优量汇(Union),加载成功"))
                    interstitialAd?.let {
                        if (biddingType == MediationConstant.AD_TYPE_CLIENT_BIDING) {
                            var epcm = interstitialAd?.ecpm?.toDouble()
                            epcm?.apply {
                                adLogWithFrame(msgs = arrayOf("GroMore-插屏-自定义优量汇(Union), 客户端竞价，ecpm:${this}"))
                                if (this < 0) {
                                    epcm = 0.0
                                }
                                callLoadSuccess(epcm!!)
                            }
                        } else {
                            adLogWithFrame(msgs = arrayOf("GroMore-插屏-自定义优量汇(Union), 竞价方式:${biddingType}"))
                            callLoadSuccess()
                        }
                    }
                }

                override fun onVideoCached() {
                }

                override fun onNoAD(adError: AdError) {
                    val msg = String.format(
                        Locale.getDefault(), "onNoAD, error code: %d, error msg: %s",
                        adError.errorCode, adError.errorMsg
                    )
                    callLoadFail(adError.errorCode, msg)
                }

                override fun onADOpened() {
                    adLogWithFrame(msgs = arrayOf("GroMore-插屏-自定义优量汇(Union),广告显示"))

                    callInterstitialAdOpened()
                }

                override fun onADExposure() {

                }

                override fun onADClicked() {
                    adLogWithFrame(msgs = arrayOf("GroMore-插屏-自定义优量汇(Union),点击广告"))
                    callInterstitialAdClick()
                }

                override fun onADLeftApplication() {
                    adLogWithFrame(msgs = arrayOf("GroMore-插屏-自定义优量汇(Union),跳转到其他页面"))
                    callInterstitialAdLeftApplication()
                }

                override fun onADClosed() {
                    adLogWithFrame(msgs = arrayOf("GroMore-插屏-自定义优量汇(Union),广告关闭"))
                    callInterstitialClosed()
                }

                override fun onRenderSuccess() {

                }

                override fun onRenderFail() {
                    callLoadFail(0, "GroMore-插屏-自定义优量汇(Union), 渲染失败")
                }
            })
            interstitialAd?.setVideoOption(
                VideoOption.Builder()
                    .setAutoPlayMuted(true)
                    .build()
            )
            interstitialAd?.loadFullScreenAD()
        }
    }

    override fun showAd(p0: Activity?) {
        adLogWithFrame(msgs = arrayOf("GroMore-插屏-自定义优量汇(Union), 展示插屏广告"))
        interstitialAd?.showFullScreenAD(p0)
    }

    override fun onDestroy() {
        super.onDestroy()
        adLogWithFrame(msgs = arrayOf("GroMore-插屏-自定义优量汇(Union), 销毁广告"))
        interstitialAd?.destroy()
    }

    override fun isReadyCondition(): MediationConstant.AdIsReadyStatus {
        if (interstitialAd == null) {
            adLogWithFrame(msgs = arrayOf("GroMore-插屏-自定义优量汇(Union), UnifiedInterstitialAD为空， 还未准备好"))
            return MediationConstant.AdIsReadyStatus.AD_IS_NOT_READY
        }
        return if (interstitialAd?.isValid == true) MediationConstant.AdIsReadyStatus.AD_IS_READY else MediationConstant.AdIsReadyStatus.AD_IS_NOT_READY

    }


    override fun receiveBidResult(win: Boolean, winnerPrice: Double, loseReason: Int, extra: MutableMap<String, Any>?) {
        super.receiveBidResult(win, winnerPrice, loseReason, extra)
        val reason = when (loseReason) {
            1 -> "价格较低"
            2 -> "广告返回超时"
            10001 -> "其他原因"
            -1 -> "胜出"
            else -> {
                ""
            }
        }
        adLogWithFrame(
            msgs = arrayOf(
                "GroMore-开屏-自定义优量汇(Union)",
                "竞价结果:${if (win) "竞价胜利" else "竞价输了"}",
                "竞价胜利价格:${winnerPrice}",
                "失败原因:${reason}",
                "extra: $extra"
            )
        )
        if (win) {
            if (winnerPrice > 0) {
                interstitialAd?.sendWinNotification(
                    mapOf(
                        IBidding.EXPECT_COST_PRICE to winnerPrice
                    )
                )
            }
        } else {
            if (loseReason == 1) {
                interstitialAd?.sendLossNotification(
                    mapOf(
                        IBidding.LOSS_REASON to 2 // 其他广告出价更高
                    )
                )
            }
        }
    }
}
