package com.composition.android.ad.gromore.union

import android.content.Context
import com.bytedance.sdk.openadsdk.mediation.bridge.custom.MediationCustomInitLoader
import com.bytedance.sdk.openadsdk.mediation.custom.MediationCustomInitConfig
import com.composition.android.ad.gromore.mediation.AdnLocalExtraConfig
import com.composition.android.lib.ad.util.adLogWithFrame
import com.qq.e.comm.managers.GDTAdSdk
import com.qq.e.comm.managers.setting.GlobalSetting
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.GlobalScope
import kotlinx.coroutines.launch


/**
 * @classname: GroMore 优量汇SDK 自定义ADN, SDK初始化
 * @author: LiuXiaoLong
 * @date: 2023/9/18
 * description: 用于在GroMore 的自定义广告网络使用
 */
class UnionInitialize : MediationCustomInitLoader() {
    override fun initializeADN(context: Context, p1: MediationCustomInitConfig, localExtra: MutableMap<String, Any>?) {
        if (!isInit) {
            GlobalScope.launch(Dispatchers.IO) {
                GDTAdSdk.init(context, p1.appId)
                val agreeAgreement = localExtra?.get(AdnLocalExtraConfig.EXTRA_AGREE_AGREEMENT) as? Boolean ?: false
                val limitPersonalAds = localExtra?.get(AdnLocalExtraConfig.EXTRA_IS_LIMIT_PERSONAL_AD) as? Boolean ?: true
                val channelId = localExtra?.get(AdnLocalExtraConfig.EXTRA_UNION_ADN_CHANNEL_ID) as? Int ?: UnionConstants.Channel.OTHER.id
                adLogWithFrame(msgs = arrayOf(
                    "GroMore-自定义广告网络-优量汇-初始化",
                    "同意隐私政策:${agreeAgreement},",
                    "允许个性化广告:${limitPersonalAds}",
                    "渠道名称:${UnionConstants.getChannelById(channelId)}"))
                GlobalSetting.setChannel(channelId)
                //设置是否已同意隐私政策
                GlobalSetting.setAgreePrivacyStrategy(agreeAgreement)
                //是否开启个性化广告 0：开启个性化广告  1：关闭个性化广告
                GlobalSetting.setPersonalizedState(if (limitPersonalAds) 0 else 1)
                adLogWithFrame(msgs = arrayOf("GroMore-自定义广告网络-优量汇-初始化完成"))

            }
        }
    }

    override fun getNetworkSdkVersion(): String {
        return "4.541.1411"
    }
}